==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/DOCUMENTENTITY_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DOCUMENTENTITY_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="DOCUMENTENTITY_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOCUMENTENTITYID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="type" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" />
 *       &lt;attribute name="copyToWO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="printOnWO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="copyToPO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="printOnPO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="createAndCopyToWO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="updateCount" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DOCUMENTENTITY_Type", propOrder = {
    "documententityid"
})
public class DOCUMENTENTITY_Type {

    @XmlElement(name = "DOCUMENTENTITYID", required = true)
    protected DOCUMENTENTITYID_Type documententityid;
    @XmlAttribute(name = "type")
    protected String type;
    @XmlAttribute(name = "copyToWO")
    protected String copyToWO;
    @XmlAttribute(name = "printOnWO")
    protected String printOnWO;
    @XmlAttribute(name = "copyToPO")
    protected String copyToPO;
    @XmlAttribute(name = "printOnPO")
    protected String printOnPO;
    @XmlAttribute(name = "createAndCopyToWO")
    protected String createAndCopyToWO;
    @XmlAttribute(name = "updateCount")
    protected Long updateCount;

    /**
     * Obtient la valeur de la propriété documententityid.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTENTITYID_Type }
     *     
     */
    public DOCUMENTENTITYID_Type getDOCUMENTENTITYID() {
        return documententityid;
    }

    /**
     * Définit la valeur de la propriété documententityid.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTENTITYID_Type }
     *     
     */
    public void setDOCUMENTENTITYID(DOCUMENTENTITYID_Type value) {
        this.documententityid = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getType() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setType(String value) {
        this.type = value;
    }

    /**
     * Obtient la valeur de la propriété copyToWO.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCopyToWO() {
        return copyToWO;
    }

    /**
     * Définit la valeur de la propriété copyToWO.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCopyToWO(String value) {
        this.copyToWO = value;
    }

    /**
     * Obtient la valeur de la propriété printOnWO.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrintOnWO() {
        return printOnWO;
    }

    /**
     * Définit la valeur de la propriété printOnWO.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPrintOnWO(String value) {
        this.printOnWO = value;
    }

    /**
     * Obtient la valeur de la propriété copyToPO.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCopyToPO() {
        return copyToPO;
    }

    /**
     * Définit la valeur de la propriété copyToPO.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCopyToPO(String value) {
        this.copyToPO = value;
    }

    /**
     * Obtient la valeur de la propriété printOnPO.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrintOnPO() {
        return printOnPO;
    }

    /**
     * Définit la valeur de la propriété printOnPO.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPrintOnPO(String value) {
        this.printOnPO = value;
    }

    /**
     * Obtient la valeur de la propriété createAndCopyToWO.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCreateAndCopyToWO() {
        return createAndCopyToWO;
    }

    /**
     * Définit la valeur de la propriété createAndCopyToWO.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCreateAndCopyToWO(String value) {
        this.createAndCopyToWO = value;
    }

    /**
     * Obtient la valeur de la propriété updateCount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUpdateCount() {
        return updateCount;
    }

    /**
     * Définit la valeur de la propriété updateCount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUpdateCount(Long value) {
        this.updateCount = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/DOCUMENTENTITY_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DOCUMENTENTITY_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DOCUMENTENTITY_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOCUMENTENTITYID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="type" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" />
 *       &lt;attribute name="copyToWO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="printOnWO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="copyToPO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="printOnPO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="createAndCopyToWO" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="updateCount" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DOCUMENTENTITY_Type", propOrder = {
    "documententityid"
})
public class DOCUMENTENTITY_Type {

    @XmlElement(name = "DOCUMENTENTITYID", required = true)
    protected DOCUMENTENTITYID_Type documententityid;
    @XmlAttribute(name = "type")
    protected String type;
    @XmlAttribute(name = "copyToWO")
    protected String copyToWO;
    @XmlAttribute(name = "printOnWO")
    protected String printOnWO;
    @XmlAttribute(name = "copyToPO")
    protected String copyToPO;
    @XmlAttribute(name = "printOnPO")
    protected String printOnPO;
    @XmlAttribute(name = "createAndCopyToWO")
    protected String createAndCopyToWO;
    @XmlAttribute(name = "updateCount")
    protected Long updateCount;

    /**
     * Gets the value of the documententityid property.
     * 
     * @return
     *     possible object is
     *     {@link DOCUMENTENTITYID_Type }
     *     
     */
    public DOCUMENTENTITYID_Type getDOCUMENTENTITYID() {
        return documententityid;
    }

    /**
     * Sets the value of the documententityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DOCUMENTENTITYID_Type }
     *     
     */
    public void setDOCUMENTENTITYID(DOCUMENTENTITYID_Type value) {
        this.documententityid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setType(String value) {
        this.type = value;
    }

    /**
     * Gets the value of the copyToWO property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCopyToWO() {
        return copyToWO;
    }

    /**
     * Sets the value of the copyToWO property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCopyToWO(String value) {
        this.copyToWO = value;
    }

    /**
     * Gets the value of the printOnWO property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrintOnWO() {
        return printOnWO;
    }

    /**
     * Sets the value of the printOnWO property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPrintOnWO(String value) {
        this.printOnWO = value;
    }

    /**
     * Gets the value of the copyToPO property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCopyToPO() {
        return copyToPO;
    }

    /**
     * Sets the value of the copyToPO property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCopyToPO(String value) {
        this.copyToPO = value;
    }

    /**
     * Gets the value of the printOnPO property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrintOnPO() {
        return printOnPO;
    }

    /**
     * Sets the value of the printOnPO property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPrintOnPO(String value) {
        this.printOnPO = value;
    }

    /**
     * Gets the value of the createAndCopyToWO property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCreateAndCopyToWO() {
        return createAndCopyToWO;
    }

    /**
     * Sets the value of the createAndCopyToWO property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCreateAndCopyToWO(String value) {
        this.createAndCopyToWO = value;
    }

    /**
     * Gets the value of the updateCount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getUpdateCount() {
        return updateCount;
    }

    /**
     * Sets the value of the updateCount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setUpdateCount(Long value) {
        this.updateCount = value;
    }

}
